@@ -40,7 +40,7 @@ class ReportResource(Resource):
     def get(self, _id: str) -> Report:
         return super(ReportResource, self)._get_with_id(_id)
 
-    def create(self, opts: ReportCreateOpts, request_opts: Optional[RequestOpts]) -> Report:
+    def create(self, opts: ReportCreateOpts, request_opts: Optional[RequestOpts] = None) -> Report:
         return super(ReportResource, self)._create(opts, request_opts)
 
     def download(self, _id: str) -> str:
